@@ -17,6 +17,7 @@ from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
+from .literals import RecordsFormatTypeType
 from .type_defs import (
     BatchExecuteStatementResponseTypeDef,
     BeginTransactionResponseTypeDef,
@@ -40,6 +41,7 @@ class BotocoreClientError(BaseException):
 
 
 class Exceptions:
+    AccessDeniedException: Type[BotocoreClientError]
     BadRequestException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     ForbiddenException: Type[BotocoreClientError]
@@ -137,6 +139,7 @@ class RDSDataServiceClient(BaseClient):
         sql: str,
         continueAfterTimeout: bool = ...,
         database: str = ...,
+        formatRecordsAs: RecordsFormatTypeType = ...,
         includeResultMetadata: bool = ...,
         parameters: Sequence["SqlParameterTypeDef"] = ...,
         resultSetOptions: "ResultSetOptionsTypeDef" = ...,
