@@ -21,6 +21,8 @@ else:
 
 __all__ = (
     "DecimalReturnTypeType",
+    "LongReturnTypeType",
+    "RecordsFormatTypeType",
     "TypeHintType",
     "RDSDataServiceServiceName",
     "ServiceName",
@@ -29,6 +31,8 @@ __all__ = (
 
 
 DecimalReturnTypeType = Literal["DOUBLE_OR_LONG", "STRING"]
+LongReturnTypeType = Literal["LONG", "STRING"]
+RecordsFormatTypeType = Literal["JSON", "NONE"]
 TypeHintType = Literal["DATE", "DECIMAL", "JSON", "TIME", "TIMESTAMP", "UUID"]
 RDSDataServiceServiceName = Literal["rds-data"]
 ServiceName = Literal[
