@@ -15,9 +15,8 @@ import sys
 from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
-from .literals import DecimalReturnTypeType, TypeHintType
+from .literals import DecimalReturnTypeType, LongReturnTypeType, RecordsFormatTypeType, TypeHintType
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -214,6 +213,7 @@ _OptionalExecuteStatementRequestRequestTypeDef = TypedDict(
     {
         "continueAfterTimeout": bool,
         "database": str,
+        "formatRecordsAs": RecordsFormatTypeType,
         "includeResultMetadata": bool,
         "parameters": Sequence["SqlParameterTypeDef"],
         "resultSetOptions": "ResultSetOptionsTypeDef",
@@ -234,6 +234,7 @@ ExecuteStatementResponseTypeDef = TypedDict(
     "ExecuteStatementResponseTypeDef",
     {
         "columnMetadata": List["ColumnMetadataTypeDef"],
+        "formattedRecords": str,
         "generatedFields": List["FieldTypeDef"],
         "numberOfRecordsUpdated": int,
         "records": List[List["FieldTypeDef"]],
@@ -245,7 +246,7 @@ FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
         "arrayValue": "ArrayValueTypeDef",
-        "blobValue": Union[bytes, IO[bytes], StreamingBody],
+        "blobValue": Union[str, bytes, IO[Any], StreamingBody],
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
@@ -296,6 +297,7 @@ ResultSetOptionsTypeDef = TypedDict(
     "ResultSetOptionsTypeDef",
     {
         "decimalReturnType": DecimalReturnTypeType,
+        "longReturnType": LongReturnTypeType,
     },
     total=False,
 )
@@ -339,7 +341,7 @@ SqlStatementResultTypeDef = TypedDict(
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List["ValueTypeDef"],
+        "attributes": List[Dict[str, Any]],
     },
     total=False,
 )
